summaryrefslogtreecommitdiffstats
path: root/test/dt_arith.c
diff options
context:
space:
mode:
authorScot Breitenfeld <brtnfld@hdfgroup.org>2021-12-07 14:27:29 (GMT)
committerGitHub <noreply@github.com>2021-12-07 14:27:29 (GMT)
commitf859cb732bd614a08189f3e133076a254035a667 (patch)
tree9c776a4ccd14729960fd0d00b5c7296fd1c7ca0b /test/dt_arith.c
parentd7466741eafcaf117818905a6cf2bcc2e798e2cc (diff)
downloadhdf5-f859cb732bd614a08189f3e133076a254035a667.zip
hdf5-f859cb732bd614a08189f3e133076a254035a667.tar.gz
hdf5-f859cb732bd614a08189f3e133076a254035a667.tar.bz2
Fixed Spelling Errors (#1166)
* fixed missed closing of a dataset * fixed missed closing of a dataset * fixed typo in error return * Committing clang-format changes * minor edits * code format * Committing clang-format changes * code format * minor edit * switched from using MPI_count, to actual bytes written for H5FD_mpio_debug rw debugging * Committing clang-format changes * changed size_i in printf to reflect the I/O. * Committing clang-format changes * Fixed seg fault with xlf on BE with -qintsize=8 * fixed error function string * spelling corrections via codespell, added new spell check github actions * Committing clang-format changes * misc * misc * misc * misc * misc * misc * misc * misc * misc * misc * misc * misc * misc * misc * Committing clang-format changes * misc * misc * misc * misc * misc * misc * Committing clang-format changes * misc * work around for https://github.com/codespell-project/codespell/issues/2137 * misc * added missing file * misc * misc. * misc * switch to using Codespell with GitHub Actions * misc. * misc. * fixed more sp errors * Fix new typos found by codespell. * fixed proceed with precede * fixed variable in fortran test * fixed minnum * updated spelling list Co-authored-by: github-actions <41898282+github-actions[bot]@users.noreply.github.com> Co-authored-by: Larry Knox <lrknox@hdfgroup.org>
Diffstat (limited to 'test/dt_arith.c')
-rw-r--r--test/dt_arith.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/test/dt_arith.c b/test/dt_arith.c
index 7e96d29..3180123 100644
--- a/test/dt_arith.c
+++ b/test/dt_arith.c
@@ -27,7 +27,7 @@
#define FP_EPSILON 0.000001F
/*
- * Offset from alinged memory returned by malloc(). This can be used to test
+ * Offset from aligned memory returned by malloc(). This can be used to test
* that type conversions handle non-aligned buffers correctly.
*/
#define ALIGNMENT 1
@@ -223,7 +223,7 @@ static int without_hardware_g = 0;
/*The number of values if multiplied by 10 for each step.*/ \
num_norm = (SRC_MAX_10_EXP - SRC_MIN_10_EXP); \
/*Reduce the number of values by 2^factor. MULTIPLY=10^(2^factor). Using this algorithm \
- *instead of arithmatic operation to avoid any conversion*/ \
+ *instead of arithmetic operation to avoid any conversion*/ \
num_norm >>= factor; \
\
/*Total number of values*/ \
@@ -640,7 +640,7 @@ test_particular_fp_integer(void)
float src_f = (float)INT_MAX;
int dst_i;
int fill_value = 13;
- int endian; /*endianess */
+ int endian; /*endianness */
unsigned int fails_this_test = 0;
size_t j;
@@ -818,7 +818,7 @@ test_derived_flt(void)
size_t src_size, dst_size;
unsigned char *buf = NULL, *saved_buf = NULL;
int * aligned = NULL;
- int endian; /*endianess */
+ int endian; /*endianness */
size_t nelmts = NTESTELEM;
unsigned int fails_this_test = 0;
const size_t max_fails = 40; /*max number of failures*/
@@ -1267,7 +1267,7 @@ test_derived_integer(void)
char filename[1024];
size_t src_size, dst_size;
unsigned char *buf = NULL, *saved_buf = NULL;
- int endian; /*endianess */
+ int endian; /*endianness */
size_t nelmts = NTESTELEM;
unsigned int fails_this_test = 0;
const size_t max_fails = 40; /*max number of failures*/
@@ -1591,7 +1591,7 @@ test_conv_int_1(const char *name, hid_t src, hid_t dst)
dtype_t src_type, dst_type; /*data types */
const char * src_type_name = NULL; /*source type name */
const char * dst_type_name = NULL; /*destination type name */
- int endian; /*machine endianess */
+ int endian; /*machine endianness */
size_t src_size, dst_size; /*type sizes */
unsigned char * buf = NULL; /*buffer for conversion */
unsigned char * saved = NULL; /*original values */
@@ -2831,8 +2831,8 @@ test_conv_flt_1(const char *name, int run_test, hid_t src, hid_t dst)
int overflow = 0; /*overflow occurred */
int uflow = 0; /*underflow debug counters*/
size_t j, k; /*counters */
- int sendian; /* source type endianess */
- int dendian; /* Destination type endianess */
+ int sendian; /* source type endianness */
+ int dendian; /* Destination type endianness */
size_t dst_ebias; /* Destination type's exponent bias */
size_t src_epos; /* Source type's exponent position */
size_t src_esize; /* Source type's exponent size */
@@ -3147,7 +3147,7 @@ test_conv_flt_1(const char *name, int run_test, hid_t src, hid_t dst)
/*
* Assume same if both results are NaN. There are many NaN bit
- * patterns and the software doesn't attemt to emulate the
+ * patterns and the software doesn't attempt to emulate the
* hardware in this regard. Instead, software uses a single bit
* pattern for NaN by setting the significand to all ones.
*/
@@ -3426,8 +3426,8 @@ test_conv_int_fp(const char *name, int run_test, hid_t src, hid_t dst)
dtype_t dst_type; /*data types */
const char * src_type_name = NULL; /*source type name */
const char * dst_type_name = NULL; /*destination type name */
- int sendian; /*source endianess */
- int dendian; /*destination endianess */
+ int sendian; /*source endianness */
+ int dendian; /*destination endianness */
size_t src_size, dst_size; /*type sizes */
unsigned char * buf = NULL; /*buffer for conversion */
unsigned char * saved = NULL; /*original values */
@@ -4485,7 +4485,7 @@ test_conv_int_fp(const char *name, int run_test, hid_t src, hid_t dst)
break;
}
- HDprintf(" ans = ");
+ HDprintf(" and = ");
for (k = 0; k < dst_size; k++)
HDprintf(" %02x", hw[ENDIAN(dst_size, k, dendian)]);
HDprintf("%*s", (int)(3 * MAX(0, (ssize_t)src_size - (ssize_t)dst_size)), "");